/*
 * Copyright (C) 2005-2006 Andre Noll <maan@systemlinux.org>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
struct receiver_node {
	struct receiver *receiver;
	char *buf;
	size_t loaded;
	void *private_data;
	int argc;
	char **argv;
	int eof;
	int chunk_time;
	void *conf;
};

struct receiver {
	const char *name;
	int (*init)(struct receiver *r);
	int (*open)(struct receiver_node *rn);
	void (*close)(struct receiver_node *rn);
	void (*shutdown)(void);
	int (*pre_select)(struct receiver_node *rn, fd_set *rfds, fd_set *wfds, struct timeval *timeout);
	int (*post_select)(struct receiver_node *rn, int select_ret, fd_set *rfds, fd_set *wfds);
	void (*print_help)(void);
	void * (*parse_config)(int argc, char **argv);
};

enum {HEADER_WAIT = 1};

void *check_receiver_arg(char *ra, int *receiver_num);

extern struct receiver receivers[];
extern void (*crypt_function_recv)(unsigned long len, const unsigned char *indata, unsigned char *outdata);
extern void (*crypt_function_send)(unsigned long len, const unsigned char *indata, unsigned char *outdata);

extern int http_recv_init(struct receiver *r);
#ifdef HAVE_ORTP
extern int ortp_recv_init(struct receiver *r);
#define ORTP_RECEIVER {.name = "ortp", .init = ortp_recv_init},
#else
#define ORTP_RECEIVER
#endif

#define DEFINE_RECEIVER_ARRAY(ra) struct receiver ra[] = { \
	{.name = "http", .init = http_recv_init}, \
	ORTP_RECEIVER \
	{.name = NULL}};
